import { defineStore } from 'pinia';

export const useMapStore = defineStore('mapState', {
    state: () => ({
        defaultZoom: Number,
        defaultMapCenter: Object,
        currentPlace: Object,
        maxZoom: Number,
        currentZoom: Number,
        duration: 3,
    }),
    actions: {
        zoomToPlace(map, lat, long) {
            map.flyTo([lat, long], this.maxZoom, { duration: this.duration });
            this.currentZoom = this.maxZoom;
        },
        resetMap(map) {
            map.flyTo(this.defaultMapCenter, this.defaultZoom, { duration: this.duration });
            this.currentZoom = this.defaultZoom;
        },
        lockMap(map) {
            setTimeout(() => {
                map.options.minZoom = this.currentZoom;
                map.options.maxZoom = this.currentZoom;
            }, this.duration * 1000 + 100);
            map.dragging.disable();
            map.touchZoom.disable();
            map.doubleClickZoom.disable();
            map.scrollWheelZoom.disable();
            map.boxZoom.disable();
            map.keyboard.disable();
            // map.tap.disable();
          },
          unlockMap(map) {
            map.options.minZoom = this.defaultZoom;
            map.options.maxZoom = this.maxZoom;
            map.dragging.enable();
            map.touchZoom.enable();
            map.doubleClickZoom.enable();
            map.scrollWheelZoom.enable();
            map.boxZoom.enable();
            map.keyboard.enable();
            // map.tap.enable();
          },
    },
});